@@ -2,6 +2,6 @@
 # | |  |   |
 # '_'  '   '--
 __title__ = "otl"
-__version__ = "1.0.7"
+__version__ = "1.10.0"
 __license__ = "MIT"
-__author__ = "xuyong,lixuguang"
+__author__ = "xuyong"
